<?php

namespace Drupal\Tests\required_by_role\Unit;

use Drupal\Core\Session\AccountInterface;
use Drupal\Tests\UnitTestCase;
use Drupal\required_by_role\Plugin\Required\RequiredByRole;
use PHPUnit\Framework\MockObject\MockObject;

/**
 * Tests the required_by_role plugin.
 *
 * @group required_by_role
 *
 * @see \Drupal\required_by_role\Plugin\Required\RequiredByRole
 */
class RequiredByRoleTest extends UnitTestCase {

  /**
   * The required plugin.
   */
  protected RequiredByRole|MockObject $plugin;

  /**
   * Caching the plugin instance in the $plugin property.
   */
  public function setUp(): void {
    parent::setUp();
    $this->plugin = $this->getMockBuilder('Drupal\required_by_role\Plugin\Required\RequiredByRole')
      ->disableOriginalConstructor()
      ->onlyMethods([])
      ->getMock();
  }

  /**
   * Tests the required by role behavior.
   *
   * @dataProvider getRequiredCases
   */
  public function testRequiredByRole($result, $user_roles, $required_roles): void {
    $required = $this->plugin->getMatches($user_roles, $required_roles);
    $this->assertEquals($result, $required);
  }

  /**
   * Provides a cases to test.
   */
  public static function getRequiredCases(): array {
    return [
      // User with matching roles.
      [
        TRUE,
        [
          AccountInterface::AUTHENTICATED_ROLE,
          'administrator',
        ],
        [
          'administrator',
        ],
      ],
      // User with no matching roles.
      [
        FALSE,
        [
          AccountInterface::AUTHENTICATED_ROLE,
          'administrator',
        ],
        [
          AccountInterface::ANONYMOUS_ROLE,
        ],
      ],
      // No required roles set.
      [
        FALSE,
        [
          AccountInterface::AUTHENTICATED_ROLE,
          'administrator',
        ],
        [],
      ],
    ];
  }

}
